Brian2GeNN
==========

Brian 2 frontend to the GeNN simulator

[![Build Status](https://dev.azure.com/brian-team/Brian2GeNN/_apis/build/status/brian-team.brian2genn)](https://dev.azure.com/brian-team/Brian2GeNN/_build/latest?definitionId=1)
